"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// istanbul ignore file
const path_1 = __importDefault(require("path"));
const core_1 = require("@oclif/core");
const fs_extra_1 = __importDefault(require("fs-extra"));
const inquirer_1 = __importDefault(require("inquirer"));
const base_command_1 = __importDefault(require("../base-command"));
const config_1 = require("../config");
const provider_1 = require("../provider");
class CheckCommand extends base_command_1.default {
    static description = '查询 Provider';
    static args = {
        provider: core_1.Args.string({
            description: '发起检查的 Provider',
            required: true,
        }),
    };
    async run() {
        const nodeList = await this.getNodeList(this.args.provider);
        if (!process.stdin.isTTY) {
            console.log(JSON.stringify(nodeList, null, 2));
            return;
        }
        const answers = await inquirer_1.default.prompt([
            {
                type: 'list',
                name: 'node',
                message: '请选择节点',
                choices: nodeList.map((node) => {
                    const name = 'hostname' in node && 'port' in node
                        ? `${node.nodeName} - ${node.hostname}:${node.port}`
                        : node.nodeName;
                    return {
                        name,
                        value: node,
                    };
                }),
            },
        ]);
        console.log(JSON.stringify(answers.node, null, 2));
        await this.cleanup();
    }
    async getNodeList(providerName) {
        core_1.ux.action.start('正在获取 Provider 信息');
        const config = (0, config_1.getConfig)();
        const filePath = path_1.default.resolve(config.providerDir, `./${providerName}.js`);
        const file = fs_extra_1.default.existsSync(filePath)
            ? await Promise.resolve(`${filePath}`).then(s => __importStar(require(s)))
            : new Error('找不到该 Provider');
        if (file instanceof Error) {
            throw file;
        }
        const provider = await (0, provider_1.getProvider)(providerName, file.default);
        const nodeList = await provider.getNodeList();
        core_1.ux.action.stop();
        return nodeList;
    }
}
exports.default = CheckCommand;
//# sourceMappingURL=check.js.map