"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// istanbul ignore file
const fs_1 = require("fs");
const path_1 = require("path");
const logger_1 = require("@surgio/logger");
const base_command_1 = __importDefault(require("../base-command"));
const provider_1 = require("../provider");
const utils_1 = require("../utils");
const logger = (0, logger_1.createLogger)({
    service: 'surgio:SubscriptionsCommand',
});
class SubscriptionsCommand extends base_command_1.default {
    static description = '查询订阅信息';
    async run() {
        const providerList = await this.listProviders();
        for (const provider of providerList) {
            if (provider.supportGetSubscriptionUserInfo) {
                const userInfo = await provider.getSubscriptionUserInfo();
                if (userInfo) {
                    const format = (0, utils_1.formatSubscriptionUserInfo)(userInfo);
                    console.log('🤟 %s 已用流量：%s 剩余流量：%s 有效期至：%s', provider.name, format.used, format.left, format.expire);
                }
                else {
                    console.log('⚠️  无法查询 %s 的流量信息', provider.name);
                }
            }
            else {
                console.log('⚠️  无法查询 %s 的流量信息', provider.name);
            }
        }
        await this.cleanup();
    }
    async listProviders() {
        const files = await fs_1.promises.readdir(this.surgioConfig.providerDir, {
            encoding: 'utf8',
        });
        const providerList = [];
        async function readProvider(path) {
            let provider;
            try {
                const providerName = (0, path_1.basename)(path, '.js');
                const module = await Promise.resolve(`${path}`).then(s => __importStar(require(s)));
                logger.debug('read %s %s', providerName, path);
                // eslint-disable-next-line prefer-const
                provider = await (0, provider_1.getProvider)(providerName, module.default);
            }
            catch (err) {
                logger.debug(`${path} 不是一个合法的模块`);
                return undefined;
            }
            if (!provider?.type) {
                logger.debug(`${path} 不是一个 Provider`);
                return undefined;
            }
            logger.debug('got provider %j', provider);
            return provider;
        }
        for (const file of files) {
            const result = await readProvider((0, path_1.join)(this.surgioConfig.providerDir, file));
            if (result) {
                providerList.push(result);
            }
        }
        return providerList;
    }
}
exports.default = SubscriptionsCommand;
//# sourceMappingURL=subscriptions.js.map