import { z } from 'zod';
import { NodeTypeEnum } from '../types';
export declare const VlessRealityOptsValidator: z.ZodObject<{
    publicKey: z.ZodString;
    shortId: z.ZodOptional<z.ZodString>;
    spiderX: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    publicKey: string;
    shortId?: string | undefined;
    spiderX?: string | undefined;
}, {
    publicKey: string;
    shortId?: string | undefined;
    spiderX?: string | undefined;
}>;
export declare const VlessNodeConfigValidator: z.ZodObject<{
    nodeName: z.ZodString;
    enable: z.ZodOptional<z.ZodBoolean>;
    tfo: z.ZodOptional<z.ZodBoolean>;
    mptcp: z.ZodOptional<z.ZodBoolean>;
    ecn: z.ZodOptional<z.ZodBoolean>;
    sni: z.ZodOptional<z.ZodString>;
    shadowTls: z.ZodOptional<z.ZodObject<{
        version: z.ZodOptional<z.ZodEffects<z.ZodUnion<[z.ZodString, z.ZodNumber]>, string | number, string | number>>;
        password: z.ZodString;
        sni: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        password: string;
        sni: string;
        version?: string | number | undefined;
    }, {
        password: string;
        sni: string;
        version?: string | number | undefined;
    }>>;
    blockQuic: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"auto">, z.ZodLiteral<"on">, z.ZodLiteral<"off">]>>;
    portHopping: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
    portHoppingInterval: z.ZodOptional<z.ZodNumber>;
    underlyingProxy: z.ZodOptional<z.ZodString>;
    testUrl: z.ZodOptional<z.ZodString>;
    testTimeout: z.ZodOptional<z.ZodNumber>;
    surgeConfig: z.ZodOptional<z.ZodObject<{
        resolveHostname: z.ZodOptional<z.ZodBoolean>;
        vmessAEAD: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        resolveHostname?: boolean | undefined;
        vmessAEAD?: boolean | undefined;
    }, {
        resolveHostname?: boolean | undefined;
        vmessAEAD?: boolean | undefined;
    }>>;
    surfboardConfig: z.ZodOptional<z.ZodObject<{
        vmessAEAD: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        vmessAEAD?: boolean | undefined;
    }, {
        vmessAEAD?: boolean | undefined;
    }>>;
    quantumultXConfig: z.ZodOptional<z.ZodObject<{
        vmessAEAD: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        vmessAEAD?: boolean | undefined;
    }, {
        vmessAEAD?: boolean | undefined;
    }>>;
    clashConfig: z.ZodOptional<z.ZodObject<{
        enableTuic: z.ZodOptional<z.ZodBoolean>;
        enableShadowTls: z.ZodOptional<z.ZodBoolean>;
        enableHysteria2: z.ZodOptional<z.ZodBoolean>;
        enableVless: z.ZodOptional<z.ZodBoolean>;
        clashCore: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"clash">, z.ZodLiteral<"clash.meta">, z.ZodLiteral<"stash">]>>;
    }, "strip", z.ZodTypeAny, {
        enableTuic?: boolean | undefined;
        enableShadowTls?: boolean | undefined;
        enableHysteria2?: boolean | undefined;
        enableVless?: boolean | undefined;
        clashCore?: "clash" | "clash.meta" | "stash" | undefined;
    }, {
        enableTuic?: boolean | undefined;
        enableShadowTls?: boolean | undefined;
        enableHysteria2?: boolean | undefined;
        enableVless?: boolean | undefined;
        clashCore?: "clash" | "clash.meta" | "stash" | undefined;
    }>>;
    hostnameIp: z.ZodOptional<z.ZodReadonly<z.ZodArray<z.ZodString, "many">>>;
    binPath: z.ZodOptional<z.ZodString>;
    localPort: z.ZodOptional<z.ZodNumber>;
    interfaceName: z.ZodOptional<z.ZodString>;
    ipVersion: z.ZodOptional<z.ZodString>;
    tls13: z.ZodOptional<z.ZodBoolean>;
    skipCertVerify: z.ZodOptional<z.ZodBoolean>;
    alpn: z.ZodOptional<z.ZodArray<z.ZodString, "atleastone">>;
    serverCertFingerprintSha256: z.ZodOptional<z.ZodString>;
    clientFingerprint: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<NodeTypeEnum.Vless>;
    hostname: z.ZodString;
    port: z.ZodEffects<z.ZodUnion<[z.ZodString, z.ZodNumber]>, string | number, string | number>;
    method: z.ZodLiteral<"none">;
    uuid: z.ZodString;
    network: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"tcp">, z.ZodLiteral<"ws">, z.ZodLiteral<"h2">, z.ZodLiteral<"http">, z.ZodLiteral<"grpc">, z.ZodLiteral<"quic">, z.ZodLiteral<"httpupgrade">]>>;
    udpRelay: z.ZodOptional<z.ZodBoolean>;
    flow: z.ZodOptional<z.ZodString>;
    wsOpts: z.ZodOptional<z.ZodObject<{
        path: z.ZodString;
        headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        path: string;
        headers?: Record<string, string> | undefined;
    }, {
        path: string;
        headers?: Record<string, string> | undefined;
    }>>;
    h2Opts: z.ZodOptional<z.ZodObject<{
        path: z.ZodString;
        host: z.ZodArray<z.ZodString, "atleastone">;
    }, "strip", z.ZodTypeAny, {
        host: [string, ...string[]];
        path: string;
    }, {
        host: [string, ...string[]];
        path: string;
    }>>;
    httpOpts: z.ZodOptional<z.ZodObject<{
        path: z.ZodArray<z.ZodString, "many">;
        headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        method: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        path: string[];
        method: string;
        headers?: Record<string, string> | undefined;
    }, {
        path: string[];
        headers?: Record<string, string> | undefined;
        method?: string | undefined;
    }>>;
    grpcOpts: z.ZodOptional<z.ZodObject<{
        serviceName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        serviceName: string;
    }, {
        serviceName: string;
    }>>;
    quicOpts: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
    httpUpgradeOpts: z.ZodOptional<z.ZodObject<{
        path: z.ZodString;
        host: z.ZodOptional<z.ZodString>;
        headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        path: string;
        host?: string | undefined;
        headers?: Record<string, string> | undefined;
    }, {
        path: string;
        host?: string | undefined;
        headers?: Record<string, string> | undefined;
    }>>;
    realityOpts: z.ZodOptional<z.ZodObject<{
        publicKey: z.ZodString;
        shortId: z.ZodOptional<z.ZodString>;
        spiderX: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        publicKey: string;
        shortId?: string | undefined;
        spiderX?: string | undefined;
    }, {
        publicKey: string;
        shortId?: string | undefined;
        spiderX?: string | undefined;
    }>>;
    multiplex: z.ZodOptional<z.ZodObject<{
        protocol: z.ZodEnum<["smux", "yamux", "h2mux"]>;
        maxConnections: z.ZodOptional<z.ZodNumber>;
        minStreams: z.ZodOptional<z.ZodNumber>;
        maxStreams: z.ZodOptional<z.ZodNumber>;
        padding: z.ZodOptional<z.ZodBoolean>;
        brutal: z.ZodOptional<z.ZodObject<{
            upMbps: z.ZodNumber;
            downMbps: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            upMbps: number;
            downMbps: number;
        }, {
            upMbps: number;
            downMbps: number;
        }>>;
    }, "strip", z.ZodTypeAny, {
        protocol: "smux" | "yamux" | "h2mux";
        maxConnections?: number | undefined;
        minStreams?: number | undefined;
        maxStreams?: number | undefined;
        padding?: boolean | undefined;
        brutal?: {
            upMbps: number;
            downMbps: number;
        } | undefined;
    }, {
        protocol: "smux" | "yamux" | "h2mux";
        maxConnections?: number | undefined;
        minStreams?: number | undefined;
        maxStreams?: number | undefined;
        padding?: boolean | undefined;
        brutal?: {
            upMbps: number;
            downMbps: number;
        } | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    port: string | number;
    type: NodeTypeEnum.Vless;
    nodeName: string;
    hostname: string;
    method: "none";
    uuid: string;
    network: "tcp" | "http" | "ws" | "h2" | "grpc" | "quic" | "httpupgrade";
    enable?: boolean | undefined;
    tfo?: boolean | undefined;
    mptcp?: boolean | undefined;
    ecn?: boolean | undefined;
    sni?: string | undefined;
    shadowTls?: {
        password: string;
        sni: string;
        version?: string | number | undefined;
    } | undefined;
    blockQuic?: "auto" | "on" | "off" | undefined;
    portHopping?: string | undefined;
    portHoppingInterval?: number | undefined;
    underlyingProxy?: string | undefined;
    testUrl?: string | undefined;
    testTimeout?: number | undefined;
    surgeConfig?: {
        resolveHostname?: boolean | undefined;
        vmessAEAD?: boolean | undefined;
    } | undefined;
    surfboardConfig?: {
        vmessAEAD?: boolean | undefined;
    } | undefined;
    quantumultXConfig?: {
        vmessAEAD?: boolean | undefined;
    } | undefined;
    clashConfig?: {
        enableTuic?: boolean | undefined;
        enableShadowTls?: boolean | undefined;
        enableHysteria2?: boolean | undefined;
        enableVless?: boolean | undefined;
        clashCore?: "clash" | "clash.meta" | "stash" | undefined;
    } | undefined;
    hostnameIp?: readonly string[] | undefined;
    binPath?: string | undefined;
    localPort?: number | undefined;
    interfaceName?: string | undefined;
    ipVersion?: string | undefined;
    tls13?: boolean | undefined;
    skipCertVerify?: boolean | undefined;
    alpn?: [string, ...string[]] | undefined;
    serverCertFingerprintSha256?: string | undefined;
    clientFingerprint?: string | undefined;
    udpRelay?: boolean | undefined;
    flow?: string | undefined;
    wsOpts?: {
        path: string;
        headers?: Record<string, string> | undefined;
    } | undefined;
    h2Opts?: {
        host: [string, ...string[]];
        path: string;
    } | undefined;
    httpOpts?: {
        path: string[];
        method: string;
        headers?: Record<string, string> | undefined;
    } | undefined;
    grpcOpts?: {
        serviceName: string;
    } | undefined;
    quicOpts?: {} | undefined;
    httpUpgradeOpts?: {
        path: string;
        host?: string | undefined;
        headers?: Record<string, string> | undefined;
    } | undefined;
    realityOpts?: {
        publicKey: string;
        shortId?: string | undefined;
        spiderX?: string | undefined;
    } | undefined;
    multiplex?: {
        protocol: "smux" | "yamux" | "h2mux";
        maxConnections?: number | undefined;
        minStreams?: number | undefined;
        maxStreams?: number | undefined;
        padding?: boolean | undefined;
        brutal?: {
            upMbps: number;
            downMbps: number;
        } | undefined;
    } | undefined;
}, {
    port: string | number;
    type: NodeTypeEnum.Vless;
    nodeName: string;
    hostname: string;
    method: "none";
    uuid: string;
    enable?: boolean | undefined;
    tfo?: boolean | undefined;
    mptcp?: boolean | undefined;
    ecn?: boolean | undefined;
    sni?: string | undefined;
    shadowTls?: {
        password: string;
        sni: string;
        version?: string | number | undefined;
    } | undefined;
    blockQuic?: "auto" | "on" | "off" | undefined;
    portHopping?: string | undefined;
    portHoppingInterval?: number | undefined;
    underlyingProxy?: string | undefined;
    testUrl?: string | undefined;
    testTimeout?: number | undefined;
    surgeConfig?: {
        resolveHostname?: boolean | undefined;
        vmessAEAD?: boolean | undefined;
    } | undefined;
    surfboardConfig?: {
        vmessAEAD?: boolean | undefined;
    } | undefined;
    quantumultXConfig?: {
        vmessAEAD?: boolean | undefined;
    } | undefined;
    clashConfig?: {
        enableTuic?: boolean | undefined;
        enableShadowTls?: boolean | undefined;
        enableHysteria2?: boolean | undefined;
        enableVless?: boolean | undefined;
        clashCore?: "clash" | "clash.meta" | "stash" | undefined;
    } | undefined;
    hostnameIp?: string[] | undefined;
    binPath?: string | undefined;
    localPort?: number | undefined;
    interfaceName?: string | undefined;
    ipVersion?: string | undefined;
    tls13?: boolean | undefined;
    skipCertVerify?: boolean | undefined;
    alpn?: [string, ...string[]] | undefined;
    serverCertFingerprintSha256?: string | undefined;
    clientFingerprint?: string | undefined;
    network?: "tcp" | "http" | "ws" | "h2" | "grpc" | "quic" | "httpupgrade" | undefined;
    udpRelay?: boolean | undefined;
    flow?: string | undefined;
    wsOpts?: {
        path: string;
        headers?: Record<string, string> | undefined;
    } | undefined;
    h2Opts?: {
        host: [string, ...string[]];
        path: string;
    } | undefined;
    httpOpts?: {
        path: string[];
        headers?: Record<string, string> | undefined;
        method?: string | undefined;
    } | undefined;
    grpcOpts?: {
        serviceName: string;
    } | undefined;
    quicOpts?: {} | undefined;
    httpUpgradeOpts?: {
        path: string;
        host?: string | undefined;
        headers?: Record<string, string> | undefined;
    } | undefined;
    realityOpts?: {
        publicKey: string;
        shortId?: string | undefined;
        spiderX?: string | undefined;
    } | undefined;
    multiplex?: {
        protocol: "smux" | "yamux" | "h2mux";
        maxConnections?: number | undefined;
        minStreams?: number | undefined;
        maxStreams?: number | undefined;
        padding?: boolean | undefined;
        brutal?: {
            upMbps: number;
            downMbps: number;
        } | undefined;
    } | undefined;
}>;
